summaryrefslogtreecommitdiffhomepage
path: root/release
diff options
context:
space:
mode:
authorRay <[email protected]>2018-06-02 13:05:23 +0200
committerRay <[email protected]>2018-06-02 13:05:23 +0200
commitb1b4a11bdb450c415ae54eded7f868af19a7fb5d (patch)
treef8a44ca57434e002d265e907bddd01ff1b871823 /release
parent0c1bc039a26351c77b80280153ede9bf4d909821 (diff)
downloadraylib-b1b4a11bdb450c415ae54eded7f868af19a7fb5d.tar.gz
raylib-b1b4a11bdb450c415ae54eded7f868af19a7fb5d.zip
Corrected issue with function definition
Diffstat (limited to 'release')
-rw-r--r--release/include/raylib.h5
-rw-r--r--release/libs/win32/tcc/libraylib.abin1463102 -> 1463584 bytes
2 files changed, 3 insertions, 2 deletions
diff --git a/release/libs/win32/tcc/libraylib.a b/release/libs/win32/tcc/libraylib.a
index 94114ac0..0d1d4549 100644
--- a/release/libs/win32/tcc/libraylib.a
+++ b/release/libs/win32/tcc/libraylib.a
Binary files differ
diff --git a/release/include/raylib.h b/release/include/raylib.h
index e83650e6..dad08ba2 100644
--- a/release/include/raylib.h
+++ b/release/include/raylib.h
@@ -912,8 +912,9 @@ RLAPI void ImageAlphaClear(Image *image, Color color, float threshold);
RLAPI void ImageAlphaCrop(Image *image, float threshold); // Crop image depending on alpha value
RLAPI void ImageAlphaPremultiply(Image *image); // Premultiply alpha channel
RLAPI void ImageCrop(Image *image, Rectangle crop); // Crop an image to a defined rectangle
-RLAPI void ImageResize(Image *image, int newWidth, int newHeight); // Resize and image (bilinear filtering)
-RLAPI void ImageResizeNN(Image *image,int newWidth,int newHeight); // Resize and image (Nearest-Neighbor scaling algorithm)
+RLAPI void ImageResize(Image *image, int newWidth, int newHeight); // Resize image (bilinear filtering)
+RLAPI void ImageResizeNN(Image *image, int newWidth,int newHeight); // Resize image (Nearest-Neighbor scaling algorithm)
+RLAPI void ImageResizeCanvas(Image *image, int newWidth, int newHeight, int offsetX, int offsetY, Color color); // Resize canvas and fill with color
RLAPI void ImageMipmaps(Image *image); // Generate all mipmap levels for a provided image
RLAPI void ImageDither(Image *image, int rBpp, int gBpp, int bBpp, int aBpp); // Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
RLAPI Image ImageText(const char *text, int fontSize, Color color); // Create an image from text (default font)